@@ -1,19 +1,19 @@
-#' minTrial
+#' Minimum number of trials needed for a specific level of power
 #'
-#' Calculate minimum number of trials for wanted power in a meta-analysis with
-#' heterogeneity
+#' Calculates minimum number of trials needed to achieve power in a meta-analysis with
+#' heterogeneity. 
 #'
-#' @param outcome Metric of interest, options include only risk ratio (RR) for now
-#' @param mc Minimal clinical relevant value.
-#' @param tau2 Heterogeneity estimate
-#' @param alpha Type I error
-#' @param beta Type II error
-#' @param p0 Probability of event in control group
-#' @param p1 Probability of event in treatment group
+#' @param outcome Metric of interest, options include "RR" (relative risk), "OR" (odds ratio), "RD" (risk difference) and "MD" (mean difference).
+#' @param mc Minimal clinical relevant value provided as a numeric value. Such as 0.8 for e.g. an odds ratio of 0.8. 
+#' @param tau2 Heterogeneity estimate. Can be extracted from the metaanalysis() function.
+#' @param alpha The level of type I error as a percentage, the default is 0.05 corresponding to 5\%.
+#' @param beta The level of type II error as a percentage, the default is 0.1 corresponding to 10\%.
 #' @param side Whether a 1- or 2-sided hypothesis test is used. Options are 1 or 2.
-#' @param var_mc Variance of the estimated effect
-#' @param var_random Estimated variance from the random-effects meta-analysis
-#' @param trials optional number of trials.
+#' @param pC Probability of event in control group. Only used for outcomes "RR", "OR" and "RD".
+#' @param p1 Probability of event in treatment group. Only used for outcome "RD".
+#' @param var_mc Variance of the estimated effect when outcome is "MD". Not required for outcome types "OR", "RR" or "RD".
+#' @param var_random Estimated variance from the random-effects meta-analysis. Used then a meta-analysis have already been made previously.
+#' @param trials Optional argument. Number of trials of interest for to provide the number of participants needed for that exact number of trials.
 #'
 #' @return Either a number (minimum required trials) or the minimum required
 #' required trials together with a matrix of required participants per trial given
@@ -23,15 +23,23 @@
 #' @importFrom stats uniroot qnorm
 #'
 #' @examples
-#' minTrial(outcome = "RR", p0 = 0.5, mc = 0.7, tau2 = 0.05)
+#' # Minimum number of trials for a prospective meta-analysis
+#' minTrial(outcome = "RR", pC = 0.5, mc = 0.7, tau2 = 0.05, alpha = 0.05,
+#' beta = 0.1, side = 2)
+#' 
+#' # Minimum number of trials still needed for a retrospective meta-analysis
+#' # Note that retrospective sample size calculations are prone to bias
+#' ma <- metaanalysis(outcome = "RR", data = perioOxy)
+#' ris(outcome = "RR", mc = 0.80, ma = ma, type = "retrospective", fixed = FALSE,
+#'  beta = 0.1, alpha = 0.05, side = 2)
 #'
 minTrial = function(outcome,
                     mc,
                     tau2,
-                    alpha = 0.05,
-                    beta = 0.2,
-                    side = 2,
-                    p0 = NULL,
+                    alpha,
+                    beta,
+                    side,
+                    pC = NULL,
                     p1 = NULL,
                     var_mc = NULL,
                     var_random = NULL,
@@ -44,34 +52,32 @@ minTrial = function(outcome,
   war_het <- NULL
 
   if(!is.null(var_random)){
-    ntrial_random = function(mc, trial, alpha, beta, tau2, var_random) {
+    ntrial_random = function(mc, trial, alpha, beta, tau2, side,  var_random) {
       trial / ((qnorm(1 - alpha / side) + qnorm(1 - beta)) ^ 2/mc^2-1/var_random) - tau2
     }
-
+    
     minTrial <- try(ceiling(uniroot(
       function(trial)
-        ntrial_random(mc, trial, alpha, beta, tau2, var_random),
+        ntrial_random(mc, trial, alpha, beta, tau2, side, var_random),
       interval = c(0, 1000)
     )$root), TRUE)
     if(inherits(minTrial,"try-error")){
-      fixed <- TRUE
       war_het <- c("Too low est. heterogeneity to calculate RIS based on tau^2.")
     }
   } else {
-    ntrial = function(mc, trial, alpha, beta, tau2) {
+    ntrial = function(mc, trial, alpha, beta, tau2, side) {
       trial / ((qnorm(1 - alpha / side) + qnorm(1 - beta)) ^ 2/mc^2) - tau2
     }
 
     minTrial <- ceiling(uniroot(
       function(trial)
-        ntrial(mc, trial, alpha, beta, tau2),
+        ntrial(mc, trial, alpha, beta, tau2, side),
       interval = c(0, 1000)
     )$root)
   }
 
   if (outcome == "RR") {
-    pI <- exp(log(p0) + mc / 2)
-    pC <- exp(log(p0) - mc / 2)
+    pI <- exp(log(pC) + mc)
     var_mc <- 1 / pC + 1 / pI - 2
   } else if (outcome == "OR") {
     logit <- function(x)
@@ -79,14 +85,13 @@ minTrial = function(outcome,
     invlogit <- function(x)
       1 / (1 + exp(-x))
 
-    pI <- invlogit(logit(p0) + mc / 2)
-    pC <- invlogit(logit(p0) - mc / 2)
+    pI <- invlogit(logit(pC) + mc)
     var_mc <- 1 / pI + 1 / pC + 1 / (1 - pI) + 1 / (1 - pC)
   } else if(outcome == "RD"){
-    var_mc <- p0*(1-p0)+p1*(1-p1)
+    var_mc <- pC*(1-pC)+p1*(1-p1)
   }
 
-  if(fixed == FALSE){
+  if(fixed == FALSE & is.null(war_het)){
     out.mat = matrix(NA, ncol = 4, nrow = 3)
     out.mat[1, ] <- c(minTrial, minTrial + 1, minTrial + 2, minTrial + 3)
     if(is.null(var_random)){
@@ -130,18 +135,19 @@ minTrial = function(outcome,
 #' @param outcome Choose between: "MD" (mean difference), "RR" (relative risk), "OR" (odds ratio) or "RD" (risk difference).
 #' @param mc Minimum clinical relevant effect. For "OR" or "RR" set to natural scale, not log scale.
 #' @param side Test type. Set to 1 or 2 depending on the test being 1- or 2-sided.
-#' @param alpha Level of type-I-error. Default value is 0.05.
-#' @param beta Level of type-II-error. Default value is 0.2.
-#' @param fixed Should sample size be based on a fixed- or random-effects model. Defaults to TRUE.
-#' @param sd_mc Standard deviation of estimated effect. Only needed when outcome = "MD".
-#' @param p0 Probability of event in control group.
-#' @param p1 Probability of event in treatment group.
-#' @param ma An optional \code{metaanalysis} object. 
+#' @param alpha The level of type I error as a percentage, the default is 0.05 corresponding to 5\%.
+#' @param beta The level of type II error as a percentage, the default is 0.1 corresponding to 10\%.
+#' @param fixed Should sample size be based on a fixed-effect (TRUE) or random-effects (FALSE) model. Defaults to TRUE.
+#' @param sd_mc Standard deviation of estimated effect. Only needed when outcome type is "MD".
+#' @param pC Probability of event in control group. Only needed when outcome type is "OR", "RR" or "RD".
+#' @param p1 Probability of event in treatment group. Only needed when outcome type is "RD".
+#' @param ma An optional \code{metaanalysis} object. Required for retrospective sample size calculations.
 #' @param tau2 The value of the heterogeneity. Use when estimating the sample size under a random effects model. If data is provided, the estimated heterogeneity is used instead.
-#' @param I2 Inconsistency.
-#' @param D2 Diversity.
-#' @param type Prospective or retrospective sample size calculation.
-#' @param trials optional number of trials for design.
+#' @param I2 Optional argument. Inconsistency. 
+#' @param D2 Optional argument. Diversity.
+#' @param type Whehter the type of calculaiton is for "prospective" meta-analysis or "retrospective" meta-analysis. If the type is retrospective, one should add a meta-analysis object to the function. See argument ma. 
+#' @param trials Optional numeric argument. If one is interested in a specific number of trials.
+#' @param RTSA Whether the ris function was called via the RTSA function. Purely operational argument.
 #' @param ... additional arguments
 #'
 #' @return A list of up to 6 elements:
@@ -155,13 +161,19 @@ minTrial = function(outcome,
 #' @aliases print.ris
 #'
 #' @examples
-#' ris(outcome = "RR", mc = 0.8, p0 = 0.12, fixed = TRUE)
+#' # Sample and trial size calculation for prospective meta-analysis
+#' ris(outcome = "RR", mc = 0.8, pC = 0.12, fixed = TRUE, alpha = 0.05,
+#' beta = 0.1, side = 2)
 #'
+#' # Additional sample and trial size calculation for retrospective meta-analysis 
+#' # It is calculated directly from the metaanalysis() function
 #' data("perioOxy")
 #' ma <- metaanalysis(outcome = "RR", data = perioOxy, mc = 0.8, beta = 0.2)
 #' ma$ris
+#' # Or by using the two functions in sequence
 #' ma <- metaanalysis(outcome = "RR", data = perioOxy)
-#' ris(outcome = "RR", mc = 0.8, ma = ma, type = "retrospective", fixed = FALSE, beta = 0.2)
+#' ris(outcome = "RR", mc = 0.8, ma = ma, type = "retrospective", fixed = FALSE,
+#'  beta = 0.2, alpha = 0.05, side = 2)
 ris <-
   function(outcome,
            mc,
@@ -170,7 +182,7 @@ ris <-
            beta = 0.1,
            fixed = TRUE,
            sd_mc = NULL,
-           p0 = NULL,
+           pC = NULL,
            p1 = NULL,
            ma = NULL,
            tau2 = NULL,
@@ -178,19 +190,20 @@ ris <-
            D2 = NULL,
            type = "prospective",
            trials = NULL,
+           RTSA = FALSE,
            ...) {
-
+    
     # check input
-    if (outcome == "MD" & (is.null(sd_mc) | is.null(mc))) {
+    if (outcome == "MD" & (is.null(sd_mc) | is.null(mc)) & is.null(ma)) {
       stop("For continuous outcomes provide mc and sd_mc")
     }
 
-    if (type == "prospective" & outcome %in% c("RR", "OR") & (is.null(p0) | is.null(mc))) {
-      stop("For binary outcomes OR and RR provide mc and p0.")
+    if (type == "prospective" & outcome %in% c("RR", "OR") & (is.null(pC) | is.null(mc)) & is.null(ma)) {
+      stop("For binary outcomes OR and RR provide mc and pC.")
     }
 
-    if (outcome == "RD" & (is.null(mc) | is.null(p0) | is.null(p1))) {
-      stop("For binary outcome RD provide mc, p0 and p1.")
+    if (outcome == "RD" & (is.null(mc) | is.null(pC) | is.null(p1))) {
+      stop("For binary outcome RD provide mc, pC and p1.")
     }
 
     if(type == "retrospective" & (is.null(ma))){
@@ -199,13 +212,15 @@ ris <-
 
     if ((!is.null(tau2) | !is.null(I2) | !is.null(D2) ) & fixed == TRUE) {
       fixed <- FALSE
-      warning("`fixed` is changed from TRUE to FALSE due to presence of tau2, I2 and/or D2.")
+      warning("There is provided a value for tau2, I2 and/or D2. Argument fixed is changed to FALSE.")
     }
     
+    if(!is.null(ma)) type = "retrospective"
+    
     if (type == "retrospective" & fixed == TRUE & !is.null(ma$synthesize$peR[6])) {
-      fixed <- FALSE
-      warning("`fixed` is changed from TRUE to FALSE due to presence of heterogeneity in meta-analysis.")
-    }
+      if(ma$hete_results$hete_est$tau2 != 0){
+      warning("There is presence of tau2 (heterogeneity) and hence I2 and/or D2 is not 0. Consider changing fixed to FALSE.")
+    }}
 
     # calculate theta and nu
     if (outcome %in% c("OR", "RR")) {
@@ -215,16 +230,14 @@ ris <-
       invlogit <- function(x)
         1 / (1 + exp(-x))
 
-      if(type == "retrospective" & is.null(p0)){
-        p0 <- sum(ma$metaPrepare$data$eC)/sum(ma$metaPrepare$data$nC)
+      if(type == "retrospective" & is.null(pC)){
+        pC <- sum(ma$metaPrepare$org_data$eC)/sum(ma$metaPrepare$org_data$nC)
       }
-
+      
       if (outcome == "RR") {
-        pI <- exp(log(p0) + log(mc))
-        pC <- p0
+        pI <- exp(log(pC) + log(mc))
       } else if (outcome == "OR") {
-        pI <- invlogit(logit(p0) + log(mc))
-        pC <- invlogit(logit(p0))
+        pI <- invlogit(logit(pC) + log(mc))
       }
       p <- (pC + pI) / 2
       var_mc <- p * (1 - p)
@@ -238,18 +251,18 @@ ris <-
 
     if(outcome == "RD"){
 
-      if(type == "retrospective" & is.null(p0)){
-        p0 <- (ma$metaPrepare$data$eC)/(ma$metaPrepare$data$nC)
-        p1 <- (ma$metaPrepare$data$eI)/(ma$metaPrepare$data$nI)
+      if(type == "retrospective" & is.null(pC)){
+        pC <- sum(ma$metaPrepare$org_data$eC)/sum(ma$metaPrepare$org_data$nC)
+        p1 <- sum(ma$metaPrepare$org_data$eI)/sum(ma$metaPrepare$org_data$nI)
       }
 
-      var_mc <- p0*(1-p0)+p1*(1-p1)
+      var_mc <- pC*(1-pC)+p1*(1-p1)
       mc_nf <- mc
     }
     
-    # store argumetns
+    # store arguments
     args <- mget(names(formals()),sys.frame(sys.nframe()))
-
+    
     # calculate fixed effect sample size
     NF <- 2 * (qnorm(1 - alpha / side) + qnorm(1 - beta)) ^ 2 * 2 * var_mc / mc_nf ^ 2
     NF <- ceiling(NF) + ceiling(NF) %% 2
@@ -269,17 +282,23 @@ ris <-
     
     # calculate random-effects sample size
     # when used inside metaanalysis or metaanalysis object is provided
-    if (!is.null(ma) & fixed == FALSE & !is.null(ma$synthesize$peR)) {
+    if(!is.null(ma) & fixed == FALSE & is.null(ma$synthesize$peR)){
+      fixed = TRUE
+    }
+    else if (!is.null(ma) & fixed == FALSE & !is.null(ma$synthesize$peR)) {
 
       if(outcome %in% c("RR", "OR")){
         NR_tau <- minTrial(outcome = outcome, mc = mc, alpha = alpha, side = side,
-                       beta = beta, p0 = p0, tau2 = ma$synthesize$U[1],
-                       var_random = ma$synthesize$peR[6])
-        NR_tau <- append(NR_tau, list(tau2 = ma$synthesize$ci.tau$random[1,1]))
+                       beta = beta, pC = pC, tau2 = ma$synthesize$U[1],
+                       var_random = ma$synthesize$peR[6], trials = trials)
         war_het <- NR_tau$war_het
-        if(ma$synthesize$ci.tau$random[1,2] != 0){
+        if(is.null(war_het)){ NR_tau <- append(NR_tau, list(tau2 = ma$synthesize$ci.tau$random[1,1])) 
+        } else {
+          NR_tau <- NULL
+        }
+        if(ma$synthesize$ci.tau$random[1,2] != 0 & is.null(war_het)){
         NR_tau_ll <- minTrial(outcome = outcome, mc = mc, alpha = alpha,
-                          beta = beta, p0 = p0, side = side,
+                          beta = beta, pC = pC, side = side,
                           tau2 = ma$synthesize$ci.tau$random[1,2],
                           var_random = ma$synthesize$peR[6])
         NR_tau_ll <- append(NR_tau_ll, list(tau2 = ma$synthesize$ci.tau$random[1,2]))
@@ -288,39 +307,46 @@ ris <-
         }
         if(!is.null(NR_tau)){
           NR_tau_ul <- minTrial(outcome = outcome, mc = mc, alpha = alpha,
-                          beta = beta, p0 = p0, side = side,
+                          beta = beta, pC = pC, side = side,
                           tau2 = ma$synthesize$ci.tau$random[1,3],
                           var_random = ma$synthesize$peR[6])
+          NR_tau_ul <- append(NR_tau_ul, list(tau2 = ma$synthesize$ci.tau$random[1,3]))
         } else {
           NR_tau_ul <- NULL
         }
-        NR_tau_ul <- append(NR_tau_ul, list(tau2 = ma$synthesize$ci.tau$random[1,3]))
       } else if(outcome == "RD"){
         NR_tau <- minTrial(outcome = outcome, mc = mc, alpha = alpha, side = side,
-                       beta = beta, p0 = p0, p1 = p1, tau2 = ma$synthesize$U[1],
-                       var_random = ma$synthesize$peR[6])
-        NR_tau <- append(NR_tau, list(tau2 = ma$synthesize$ci.tau$random[1,1]))
+                       beta = beta, pC = pC, p1 = p1, tau2 = ma$synthesize$U[1],
+                       var_random = ma$synthesize$peR[6], trials = trials)
         war_het <- NR_tau$war_het
-        if(ma$synthesize$ci.tau$random[1,2] != 0){
+        if(is.null(war_het)){ NR_tau <- append(NR_tau, list(tau2 = ma$synthesize$ci.tau$random[1,1])) 
+        } else {
+          NR_tau <- NULL
+        }
+        if(ma$synthesize$ci.tau$random[1,2] != 0 & is.null(war_het)){
         NR_tau_ll <- minTrial(outcome = outcome, mc = mc, alpha = alpha,
-                          beta = beta, p0 = p0, p1 = p1, side = side,
+                          beta = beta, pC = pC, p1 = p1, side = side,
                           tau2 = ma$synthesize$ci.tau$random[1,2],
                           var_random = ma$synthesize$peR[6])
-        NR_tau_ll <- append(NR_tau_ll, list(tau2 = ma$synthesize$ci.tau$random[1,2]))} else {
+        NR_tau_ll <- append(NR_tau_ll, list(tau2 = ma$synthesize$ci.tau$random[1,2]))
+        } else {
           NR_tau_ll <- NULL
         }
         NR_tau_ul <- minTrial(outcome = outcome, mc = mc, alpha = alpha,
-                          beta = beta, p0 = p0, p1 = p1, side = side,
+                          beta = beta, pC = pC, p1 = p1, side = side,
                           tau2 = ma$synthesize$ci.tau$random[1,3],
                           var_random = ma$synthesize$peR[6])
         NR_tau_ul <- append(NR_tau_ul, list(tau2 = ma$synthesize$ci.tau$random[1,3]))
       } else {
         NR_tau <- minTrial(outcome = outcome, mc = mc, alpha = alpha, side = side,
                        beta = beta, var_mc = var_mc, tau2 = ma$synthesize$U[1],
-                       var_random = ma$synthesize$peR[6])
-        NR_tau <- append(NR_tau, list(tau2 = ma$synthesize$ci.tau$random[1,1]))
+                       var_random = ma$synthesize$peR[6], trials = trials)
         war_het <- NR_tau$war_het
-        if(ma$synthesize$ci.tau$random[1,2] != 0){
+        if(is.null(war_het)){ NR_tau <- append(NR_tau, list(tau2 = ma$synthesize$ci.tau$random[1,1])) 
+        } else {
+          NR_tau <- NULL
+        }
+        if(ma$synthesize$ci.tau$random[1,2] != 0 & is.null(war_het)){
         NR_tau_ll <- minTrial(outcome = outcome, mc = mc, alpha = alpha,
                           beta = beta, var_mc = var_mc,
                           tau2 = ma$synthesize$ci.tau$random[1,2],
@@ -343,7 +369,7 @@ ris <-
       NR_tau[names(NR_tau) == "war_het"] <- NULL
       NR_tau_ll[names(NR_tau_ll) == "war_het"] <- NULL
       NR_tau_ul[names(NR_tau_ul) == "war_het"] <- NULL
-
+      
       # sample size for inconsistency adj. and diversity adj.
       NR_D2 <- 1 / (1 - ma$synthesize$U[4]) * NF
       NR_I2 <- 1 / (1 - ma$synthesize$U[3]) * NF
@@ -351,12 +377,16 @@ ris <-
       NR_I2 <- ceiling(NR_I2) + ceiling(NR_I2) %% 2
       
       # set relative to the sample size already achieved
-        NR_tau_full <-
-          NR_tau$nPax[3, 4] + (sum(ma$metaPrepare$data$nI) + sum(ma$metaPrepare$data$nC))
+      if(is.null(NR_tau)){
+        NR_tau_full <- NULL  
+      }  else {
+      NR_tau_full <-
+          ifelse(is.null(trials),NR_tau$nPax[3, 1],NR_tau$nPax[3, 5]) + (sum(ma$metaPrepare$org_data$nI) + sum(ma$metaPrepare$org_data$nC))
+      }
         NR_I2_full <- NR_I2
         NR_D2_full <- NR_D2
-        NR_I2 <- NR_I2 - (sum(ma$metaPrepare$data$nI) + sum(ma$metaPrepare$data$nC))
-        NR_D2 <- NR_D2 - (sum(ma$metaPrepare$data$nI) + sum(ma$metaPrepare$data$nC))
+        NR_I2 <- NR_I2 - (sum(ma$metaPrepare$org_data$nI) + sum(ma$metaPrepare$org_data$nC))
+        NR_D2 <- NR_D2 - (sum(ma$metaPrepare$org_data$nI) + sum(ma$metaPrepare$org_data$nC))
 
       outlist <-
         append(outlist, list(
@@ -379,16 +409,16 @@ ris <-
 
       if(outcome %in% c("RR", "OR")){
         NR_tau <- minTrial(outcome = outcome, mc = mc, alpha = alpha,
-                       beta = beta, p0 = p0, tau2 = tau2,
-                       trials = trials)
+                       beta = beta, pC = pC, tau2 = tau2,
+                       trials = trials, side = side)
       } else if(outcome == "RD"){
         NR_tau <- minTrial(outcome = outcome, mc = mc, alpha = alpha,
-                       beta = beta, p0 = p0, p1 = p1, tau2 = tau2,
-                       trials = trials)
+                       beta = beta, pC = pC, p1 = p1, tau2 = tau2,
+                       trials = trials, side = side)
       } else{
         NR_tau <- minTrial(outcome = outcome, mc = mc, alpha = alpha,
                        beta = beta, var_mc = var_mc, tau2 = tau2,
-                       trials = trials)
+                       trials = trials, side = side)
       }
       if(!is.null(I2)){
         NR_I2 <- 1 / (1 - I2) * NF
@@ -432,39 +462,53 @@ print.ris <- function(x, ...) {
       "and a type-II-error of",
       paste0(x$settings$beta, "."), "\nThe minimum clinical relevant value is set to:", x$settings$mc, "for outcome metric", paste0(x$settings$outcome,".\n")
     )
-    cat("Additional parametres for sample size are:\n")
+    cat("Additional parameters for sample size are:\n")
     if(x$settings$outcome %in% c("RR", "OR")){
-      cat("Probability of event in the control group:", paste0(x$settings$p0, "."))
+      cat("Probability of event in the control group:", paste0(round(x$settings$pC,4), "."))
     } else if(x$settings$outcome == "MD"){
       cat("Standard deviation of the mean (standard error): ", paste0(x$settings$sd_mc, "."))
     } else {
-      cat("Probability of event in the control group:", x$settings$p0, "and probability of event in intervention group:", paste0(x$settings$p1, "."))
+      cat("Probability of event in the control group:", round(x$settings$pC,4), "and probability of event in intervention group:", paste0(x$settings$p1, "."))
+    }
+    if(!is.null(x$settings$trials)){
+      cat("\nNumber of planned trials:", x$settings$trials)
     }
     cat("\n\n")
     cat("Fixed-effect required information size:\n")
-    cat(paste(x$NF, "participants in total. \n"))
+    cat(paste(ifelse(x$settings$RTSA,x$SMA_NF,x$NF), "participants in total. \n"))
     if (x$settings$fixed == FALSE) {
       cat("\n")
       cat("Random-effects required information size:\n")
       if (!is.null(x$settings$tau2) & is.null(x$war_het)) {
+        if(!is.null(x$settings$trials)){
+          cat(
+            paste("Adjusted by tau^2:",
+                  ifelse(x$settings$RTSA,x$SMA_tau2[3, 5],x$NR_tau$nPax[3, 5]),
+                  "participants in total split over",
+                  x$NR_tau$nPax[1, 5],
+                  "trial(s).\n"
+            )
+          )  
+        } else {
         cat(
           paste("Adjusted by tau^2:",
-            x$NR_tau$nPax[3, 1],
+                ifelse(x$settings$RTSA,x$SMA_tau2[3, 5],x$NR_tau$nPax[3, 1]),
             "participants in total split over (at minimum)",
             x$NR_tau$nPax[1, 1],
             "trial(s).\n"
           )
         )
+        }
       }
       if (!is.null(x$NR_D2)) {
         cat(paste("Adjusted by diversity (D^2):",
-          x$NR_D2,
+                  ifelse(x$settings$RTSA,x$SMA_D2,x$NR_D2),
           "participants in total.\n"
         ))
       }
       if (!is.null(x$NR_I2)) {
         cat(paste("Adjusted by inconsistency (I^2):",
-          x$NR_I2,
+                  ifelse(x$settings$RTSA,x$SMA_I2,x$NR_I2),
           "participants in total.\n"
         ))
       }
@@ -487,22 +531,34 @@ print.ris <- function(x, ...) {
       cat("The number of required participants for a fixed-effect meta-analysis is reached.\n")
     } else {
       cat(paste(x$NF$NF, "participants in total are additionally required. \n"))}
-    if (x$settings$fixed == FALSE) {
+    if (x$settings$fixed == FALSE & (!is.null(x$NR_tau) | !is.null(x$NR_D2) | !is.null(x$NR_I2))) {
       cat("\n")
       cat("Random-effects required information size:\n")
       if (!is.null(x$NR_tau$NR_tau$tau2) & is.null(x$war_het)) {
-        cat(
-          paste("Adjusted by tau^2:",
-            x$NR_tau$NR_tau$nPax[3, 1],
-            "participants in total are additionally required. \nThese can be split over (at minimum)",
-            x$NR_tau$NR_tau$nPax[1, 1],
-            "trial(s).\n"
+        if(!is.null(x$settings$trials)){
+          cat(
+            paste("Adjusted by tau^2:",
+                  ifelse(x$settings$RTSA,x$SMA_tau2[3, 5],x$NR_tau$NR_tau$nPax[3, 5]),
+                  "participants are additionally required in total split over ",
+                  x$NR_tau$NR_tau$nPax[1, 5],
+                  "trial(s).\n"
+            )
+          )  
+        } else {
+          cat(
+            paste("Adjusted by tau^2:",
+                  ifelse(x$settings$RTSA,x$SMA_tau2[3, 1],x$NR_tau$NR_tau$nPax[3, 1]),
+                  "participants are additionally required in total split over (at minimum)",
+                  x$NR_tau$NR_tau$nPax[1, 1],
+                  "trial(s).\n"
+            )
           )
-        )
+        }
       }
+      
       if (!is.null(x$NR_D2$NR_D2) & x$NR_D2$NR_D2 >= 0) {
         cat(paste("Adjusted by diversity (D^2):",
-          x$NR_D2$NR_D2,
+                  ifelse(x$settings$RTSA,x$SMA_D2,x$NR_D2$NR_D2),
           "participants in total are additionally required. \n"
         ))
       } else if(!is.null(x$NR_D2$NR_D2) & x$NR_D2$NR_D2 < 0){
@@ -511,7 +567,7 @@ print.ris <- function(x, ...) {
       }
       if (!is.null(x$NR_I2$NR_I2) & x$NR_I2$NR_I2 >= 0) {
         cat(paste("Adjusted by inconsistency (I^2):",
-          x$NR_I2$NR_I2,
+                  ifelse(x$settings$RTSA,x$SMA_I2,x$NR_I2$NR_I2),
           "participants in total are additionally required.\n"
         ))
       } else if(!is.null(x$NR_I2$NR_I2) & x$NR_I2$NR_I2 < 0){cat(paste("Adjusted by inconsistency (I^2):",
